"""
This script will perform three tasks: 

1) Takes as input a spectrum in space- or tab-separated ASCII format 
(e.g. extracted from CASA or CARTA) with frequency as the first column 
(in units of GHz) and intensity as the second column (in units of Kelvin) 
and shifts the frequencies from sky to rest frequency using the source velocity.

2) Converts the spectrum from step 1) to CASSIS format (.fus).

3) Creates a telescope file with the name 'alma_#' where the number is the 
calculated diameter parameter. For this, the user must either provide the 
angular resolution and frequency of the observations, OR provide the FITS 
cube from which this script will automatically obtain the needed information.

"""

import numpy as np
from astropy.table import Table
from astropy.io import fits
import astropy.units as u
import astropy.constants as c
import os

################# INPUT PARAMETERS #####################################
# fill in these parameters before running the script

# To shift the frequencies from sky to rest frame
# -----------------------------------------------

# path to extracted spectrum
path = '/path/to/folder/'

# name of extracted spectrum (space- or tab-separated ascii file)
input_spectrum = 'afgl4176_spec_carta_extracted.txt' 

# Vlsr of source in km/s
vlsr = -52 * u.km/u.s 

# name of output CASSIS file (can be anything you want but with .fus extension)
cassis_spectrum = 'cassis_spectrum.fus'

# To make the telescope file:
# ---------------------------

# name of FITS cube from which the data was extracted, assumed to be at the path specified (optional)
file_fits = 'afgl4176.contsubs.fits'

# if you do not have a FITS cube, provide the angular resolution of the observations
# Note that the information below is ignored if you supply a FITS file above
frequency = 2.563020350000E+11 * u.Hz  # frequency of the observations in Hz
beam_major = 0.33 * u.arcsec   # beam semi-major in arcseconds
beam_minor = 0.28 * u.arcsec   # beam semi-minor in arcseconds

################# CONVERT ASCII FILE TO CASSIS FORMAT ##################
# Reading the text file with the frequency and flux
names_spectra = ['freq', 'flux',]
units_spectra = [u.GHz, u.Kelvin]
def read_data(infile, colnames, colunits):
    # read table
    data = Table.read(infile, 
        format='ascii', 
        comment='#',
        guess=False,
        names=colnames,
        data_start=0,
        delimiter='\s'
        )
    t = [data[i].__setattr__('unit', j) for (i,j) in zip(colnames, colunits)]   
    return data
spectra = read_data(os.path.join(path, input_spectrum), 
                names_spectra, 
                units_spectra)
# CASAviewer just spits out whatever you have, 
# so it might not be sorted if you have multple files open and the 
# spectral profile of each concatenated in the file.
spectra.sort(['freq'])

# this is a leftover from when I also output the 
# flux in Jansky.
spectra['int'] = spectra['flux']

# columns in finished file
colnames = ['FreqLsb','VeloLsb','FreqUsb','VeloUsb'	,'Int','DeltaF','DeltaV']

restfreq = spectra['freq'].quantity[0]
# IMPORTANT here is to use 'relativistic' 
# for large bandwidths, 'radio' should work in 
# most cases though
_vel = u.doppler_relativistic(restfreq)
vel_shifted = spectra['freq'].to(u.km / u.s, 
                            equivalencies=_vel) - vlsr
freq_shifted = vel_shifted.to(u.GHz, equivalencies=_vel)
spectra['freq_lsr'] = freq_shifted

freq = spectra['freq_lsr'].to(u.MHz)
intens = spectra['int'].quantity.value

# now we are ready to write the output to a file
# this is copy-pasted from a script from
# Audrey Coutens, with some minor changes.
def write_cassis_spectrum_file(cassis_file=None, freq=None, intensity=None, vlsr=0.0):
    nlines = len(freq)
    outfile = open(cassis_file, 'w')
    outfile.write('// number of line :'+str(nlines)+'\n')
    outfile.write('// vlsr : '+str(vlsr.value)+'\n')
    outfile.write('FreqLsb	VeloLsb	FreqUsb	VeloUsb	Int	DeltaF	DeltaV\n')
    for lin in np.arange(nlines):
        outfile.write('{0:.6f}\t0\t000.00\t000.00\t{1:3.10f}\t0.0\t0\n'.format(freq[lin], intensity[lin]))
    outfile.close()

write_cassis_spectrum_file(cassis_file=cassis_spectrum, 
        freq = freq.to(u.MHz).value, 
        intensity = intens, 
        vlsr=vlsr)

################# CREATE TELESCOPE FILE ################################

def get_diameter_size():
	file_path = os.path.join(path, file_fits)
	if os.path.exists(file_path):
		header = fits.getheader(file_path)
		try:
			freq = header['RESTFRQ']*u.Hz
		except KeyError as err:
			freq = header['CRVAL3']*u.Hz
			print(err)
			pass
		bmaj = header['BMAJ']*u.deg
		bmin = header['BMIN']*u.deg
	else:
		freq = frequency
		bmaj = beam_major
		bmin = beam_minor

	theta_c = np.sqrt(bmaj*bmin)
	diameter = 1.22*freq.to(u.m, equivalencies=u.spectral())/theta_c.to(u.rad).value
	return diameter

def write_alma_telescope_file(diameter):
	telescope_file_text = """// Diameter (m)
{}
// Frequency (MHz), Beff/Feff, IF (GHz), LSB gain (%), USB gain (%)
4.5000e+05	1.0000	16.000	1.0000	1.0000					
4.5500e+05	1.0000	16.000	1.0000	1.0000					
4.6000e+05	1.0000	16.000	1.0000	1.0000					
4.6500e+05	1.0000	16.000	1.0000	1.0000					
4.7000e+05	1.0000	16.000	1.0000	1.0000					
4.7500e+05	1.0000	16.000	1.0000	1.0000					
7.2000e+05	1.0000	16.000	1.0000	1.0000					
4.8500e+05	1.0000	16.000	1.0000	1.0000					
4.9000e+05	1.0000	16.000	1.0000	1.0000					
4.9500e+05	1.0000	16.000	1.0000	1.0000					
5.0000e+05	1.0000	16.000	1.0000	1.0000					
5.0500e+05	1.0000	16.000	1.0000	1.0000					
5.1000e+05	1.0000	16.000	1.0000	1.0000					
5.1500e+05	1.0000	16.000	1.0000	1.0000					
5.2000e+05	1.0000	16.000	1.0000	1.0000					
5.2500e+05	1.0000	16.000	1.0000	1.0000					
5.3000e+05	1.0000	16.000	1.0000	1.0000					
5.3500e+05	1.0000	16.000	1.0000	1.0000					
5.4000e+05	1.0000	16.000	1.0000	1.0000					
5.4500e+05	1.0000	16.000	1.0000	1.0000					
5.5000e+05	1.0000	16.000	1.0000	1.0000					
5.5500e+05	1.0000	16.000	1.0000	1.0000					
5.6000e+05	1.0000	16.000	1.0000	1.0000					
5.6500e+05	1.0000	16.000	1.0000	1.0000					
5.7000e+05	1.0000	16.000	1.0000	1.0000					
5.7500e+05	1.0000	16.000	1.0000	1.0000					
5.8000e+05	1.0000	16.000	1.0000	1.0000					
5.8500e+05	1.0000	16.000	1.0000	1.0000					
5.9000e+05	1.0000	16.000	1.0000	1.0000					
5.9500e+05	1.0000	16.000	1.0000	1.0000					
6.0000e+05	1.0000	16.000	1.0000	1.0000					
6.0500e+05	1.0000	16.000	1.0000	1.0000					
6.1000e+05	1.0000	16.000	1.0000	1.0000					
6.1500e+05	1.0000	16.000	1.0000	1.0000					
6.2000e+05	1.0000	16.000	1.0000	1.0000					
6.2500e+05	1.0000	16.000	1.0000	1.0000					
6.3000e+05	1.0000	16.000	1.0000	1.0000					
6.3500e+05	1.0000	16.000	1.0000	1.0000					
6.4000e+05	1.0000	16.000	1.0000	1.0000					
6.4500e+05	1.0000	16.000	1.0000	1.0000					
6.5000e+05	1.0000	16.000	1.0000	1.0000					
6.5500e+05	1.0000	16.000	1.0000	1.0000					
6.6000e+05	1.0000	16.000	1.0000	1.0000					
6.6500e+05	1.0000	16.000	1.0000	1.0000					
6.7000e+05	1.0000	16.000	1.0000	1.0000					
6.7500e+05	1.0000	16.000	1.0000	1.0000					
6.8000e+05	1.0000	16.000	1.0000	1.0000					
6.8500e+05	1.0000	16.000	1.0000	1.0000					
6.9000e+05	1.0000	16.000	1.0000	1.0000					
6.9500e+05	1.0000	16.000	1.0000	1.0000					
7.0000e+05	1.0000	16.000	1.0000	1.0000					
7.0500e+05	1.0000	16.000	1.0000	1.0000					
7.1000e+05	1.0000	16.000	1.0000	1.0000					
7.1500e+05	1.0000	16.000	1.0000	1.0000					
7.2000e+05	1.0000	16.000	1.0000	1.0000					
7.2500e+05	1.0000	16.000	1.0000	1.0000					
7.3000e+05	1.0000	16.000	1.0000	1.0000					
7.3500e+05	1.0000	16.000	1.0000	1.0000					
7.4000e+05	1.0000	16.000	1.0000	1.0000					
7.4500e+05	1.0000	16.000	1.0000	1.0000					
7.5000e+05	1.0000	16.000	1.0000	1.0000					
7.5500e+05	1.0000	16.000	1.0000	1.0000					
7.6000e+05	1.0000	16.000	1.0000	1.0000					
7.6500e+05	1.0000	16.000	1.0000	1.0000					
7.7000e+05	1.0000	16.000	1.0000	1.0000					
7.7500e+05	1.0000	16.000	1.0000	1.0000					
7.8000e+05	1.0000	16.000	1.0000	1.0000					
7.8500e+05	1.0000	16.000	1.0000	1.0000					
7.9000e+05	1.0000	16.000	1.0000	1.0000					
7.9500e+05	1.0000	16.000	1.0000	1.0000					
16.000e+05	1.0000	16.000	1.0000	1.0000					
8.0500e+05	1.0000	16.000	1.0000	1.0000					
8.1000e+05	1.0000	16.000	1.0000	1.0000					
8.1500e+05	1.0000	16.000	1.0000	1.0000					
8.2000e+05	1.0000	16.000	1.0000	1.0000					
8.2500e+05	1.0000	16.000	1.0000	1.0000					
8.3000e+05	1.0000	16.000	1.0000	1.0000					
8.3500e+05	1.0000	16.000	1.0000	1.0000					
8.4000e+05	1.0000	16.000	1.0000	1.0000					
8.4500e+05	1.0000	16.000	1.0000	1.0000					
8.5000e+05	1.0000	16.000	1.0000	1.0000					
8.5500e+05	1.0000	16.000	1.0000	1.0000					
8.6000e+05	1.0000	16.000	1.0000	1.0000					
8.6500e+05	1.0000	16.000	1.0000	1.0000					
8.7000e+05	1.0000	16.000	1.0000	1.0000					
8.7500e+05	1.0000	16.000	1.0000	1.0000					
8.8000e+05	1.0000	16.000	1.0000	1.0000					
8.8500e+05	1.0000	16.000	1.0000	1.0000					
8.9000e+05	1.0000	16.000	1.0000	1.0000					
8.9500e+05	1.0000	16.000	1.0000	1.0000					
9.0000e+05	1.0000	16.000	1.0000	1.0000					
9.0500e+05	1.0000	16.000	1.0000	1.0000					
9.1000e+05	1.0000	16.000	1.0000	1.0000					
9.1500e+05	1.0000	16.000	1.0000	1.0000					
9.2000e+05	1.0000	16.000	1.0000	1.0000					
9.2500e+05	1.0000	16.000	1.0000	1.0000					
9.3000e+05	1.0000	16.000	1.0000	1.0000					
9.3500e+05	1.0000	16.000	1.0000	1.0000					
9.4000e+05	1.0000	16.000	1.0000	1.0000					
9.4500e+05	1.0000	16.000	1.0000	1.0000					
9.5000e+05	1.0000	16.000	1.0000	1.0000					
9.5500e+05	1.0000	16.000	1.0000	1.0000					
9.6000e+05	1.0000	16.000	1.0000	1.0000					
9.6500e+05	1.0000	16.000	1.0000	1.0000					
9.7000e+05	1.0000	16.000	1.0000	1.0000					
9.7500e+05	1.0000	16.000	1.0000	1.0000					
9.8000e+05	1.0000	16.000	1.0000	1.0000					
9.8500e+05	1.0000	16.000	1.0000	1.0000					
9.9000e+05	1.0000	16.000	1.0000	1.0000					
9.9500e+05	1.0000	16.000	1.0000	1.0000					
1.0000e+06	1.0000	16.000	1.0000	1.0000					
1.0050e+06	1.0000	16.000	1.0000	1.0000					
1.0100e+06	1.0000	16.000	1.0000	1.0000					
1.0150e+06	1.0000	16.000	1.0000	1.0000					
1.0200e+06	1.0000	16.000	1.0000	1.0000					
1.0250e+06	1.0000	16.000	1.0000	1.0000					
1.0300e+06	1.0000	16.000	1.0000	1.0000					
1.0350e+06	1.0000	16.000	1.0000	1.0000					
1.0400e+06	1.0000	16.000	1.0000	1.0000					
1.0450e+06	1.0000	16.000	1.0000	1.0000					
1.0500e+06	1.0000	16.000	1.0000	1.0000					
1.0550e+06	1.0000	16.000	1.0000	1.0000					
1.0600e+06	1.0000	16.000	1.0000	1.0000					
1.0650e+06	1.0000	16.000	1.0000	1.0000					
1.0700e+06	1.0000	16.000	1.0000	1.0000					
1.0750e+06	1.0000	16.000	1.0000	1.0000					
1.0800e+06	1.0000	16.000	1.0000	1.0000					
1.0850e+06	1.0000	16.000	1.0000	1.0000					
1.0900e+06	1.0000	16.000	1.0000	1.0000					
1.0950e+06	1.0000	16.000	1.0000	1.0000					
1.1000e+06	1.0000	16.000	1.0000	1.0000					
1.1050e+06	1.0000	16.000	1.0000	1.0000					
1.1100e+06	1.0000	16.000	1.0000	1.0000					
1.1150e+06	1.0000	16.000	1.0000	1.0000					
1.1200e+06	1.0000	16.000	1.0000	1.0000					
1.1250e+06	1.0000	16.000	1.0000	1.0000					
1.1300e+06	1.0000	16.000	1.0000	1.0000					
1.1350e+06	1.0000	16.000	1.0000	1.0000					
1.1400e+06	1.0000	16.000	1.0000	1.0000					
1.1450e+06	1.0000	16.000	1.0000	1.0000					
1.1500e+06	1.0000	16.000	1.0000	1.0000					
1.1550e+06	1.0000	16.000	1.0000	1.0000					
1.1600e+06	1.0000	16.000	1.0000	1.0000					
1.1650e+06	1.0000	16.000	1.0000	1.0000					
1.1700e+06	1.0000	16.000	1.0000	1.0000					
1.1750e+06	1.0000	16.000	1.0000	1.0000					
1.1800e+06	1.0000	16.000	1.0000	1.0000					
1.1850e+06	1.0000	16.000	1.0000	1.0000					
1.1900e+06	1.0000	16.000	1.0000	1.0000					
1.1950e+06	1.0000	16.000	1.0000	1.0000					
1.2000e+06	1.0000	16.000	1.0000	1.0000					
1.2050e+06	1.0000	16.000	1.0000	1.0000					
1.2100e+06	1.0000	16.000	1.0000	1.0000					
1.2150e+06	1.0000	16.000	1.0000	1.0000					
1.2200e+06	1.0000	16.000	1.0000	1.0000					
1.2250e+06	1.0000	16.000	1.0000	1.0000					
1.2300e+06	1.0000	16.000	1.0000	1.0000					
1.2350e+06	1.0000	16.000	1.0000	1.0000					
1.2400e+06	1.0000	16.000	1.0000	1.0000					
1.2450e+06	1.0000	16.000	1.0000	1.0000					
1.2500e+06	1.0000	16.000	1.0000	1.0000					
1.2550e+06	1.0000	16.000	1.0000	1.0000					
1.2600e+06	1.0000	16.000	1.0000	1.0000					
1.2650e+06	1.0000	16.000	1.0000	1.0000					
1.2700e+06	1.0000	16.000	1.0000	1.0000					
1.2750e+06	1.0000	16.000	1.0000	1.0000					
1.2800e+06	1.0000	16.000	1.0000	1.0000					
1.2850e+06	1.0000	16.000	1.0000	1.0000					
1.2900e+06	1.0000	16.000	1.0000	1.0000					
1.2950e+06	1.0000	16.000	1.0000	1.0000					
1.3000e+06	1.0000	16.000	1.0000	1.0000					
1.3050e+06	1.0000	16.000	1.0000	1.0000					
1.3100e+06	1.0000	16.000	1.0000	1.0000					
1.3150e+06	1.0000	16.000	1.0000	1.0000					
1.3200e+06	1.0000	16.000	1.0000	1.0000					
1.3250e+06	1.0000	16.000	1.0000	1.0000					
1.3300e+06	1.0000	16.000	1.0000	1.0000					
1.3350e+06	1.0000	16.000	1.0000	1.0000					
1.3400e+06	1.0000	16.000	1.0000	1.0000					
1.3450e+06	1.0000	16.000	1.0000	1.0000					
1.3500e+06	1.0000	16.000	1.0000	1.0000					
1.3550e+06	1.0000	16.000	1.0000	1.0000					
1.3600e+06	1.0000	16.000	1.0000	1.0000					
1.3650e+06	1.0000	16.000	1.0000	1.0000					
1.3700e+06	1.0000	16.000	1.0000	1.0000					
1.3750e+06	1.0000	16.000	1.0000	1.0000					
1.3800e+06	1.0000	16.000	1.0000	1.0000					
1.3850e+06	1.0000	16.000	1.0000	1.0000					
1.3900e+06	1.0000	16.000	1.0000	1.0000					
1.3950e+06	1.0000	16.000	1.0000	1.0000					
1.4000e+06	1.0000	7.2000	1.0000	1.0000					
1.4050e+06	1.0000	7.2000	1.0000	1.0000					
1.4100e+06	1.0000	7.2000	1.0000	1.0000					
1.4150e+06	1.0000	7.2000	1.0000	1.0000					
1.4200e+06	1.0000	7.2000	1.0000	1.0000					
1.4250e+06	1.0000	7.2000	1.0000	1.0000					
1.4300e+06	1.0000	7.2000	1.0000	1.0000					
1.4350e+06	1.0000	7.2000	1.0000	1.0000					
1.4400e+06	1.0000	7.2000	1.0000	1.0000					
1.4450e+06	1.0000	7.2000	1.0000	1.0000					
1.4500e+06	1.0000	7.2000	1.0000	1.0000					
1.4550e+06	1.0000	7.2000	1.0000	1.0000					
1.4600e+06	1.0000	7.2000	1.0000	1.0000					
1.4650e+06	1.0000	7.2000	1.0000	1.0000					
1.4700e+06	1.0000	7.2000	1.0000	1.0000					
1.4750e+06	1.0000	7.2000	1.0000	1.0000					
1.4800e+06	1.0000	7.2000	1.0000	1.0000					
1.4850e+06	1.0000	7.2000	1.0000	1.0000					
1.4900e+06	1.0000	7.2000	1.0000	1.0000					
1.4950e+06	1.0000	7.2000	1.0000	1.0000					
1.5000e+06	1.0000	7.2000	1.0000	1.0000					
1.5050e+06	1.0000	7.2000	1.0000	1.0000					
1.5100e+06	1.0000	7.2000	1.0000	1.0000					
1.5150e+06	1.0000	7.2000	1.0000	1.0000					
1.5200e+06	1.0000	7.2000	1.0000	1.0000					
1.5250e+06	1.0000	7.2000	1.0000	1.0000					
1.5300e+06	1.0000	7.2000	1.0000	1.0000					
1.5350e+06	1.0000	7.2000	1.0000	1.0000					
1.5400e+06	1.0000	7.2000	1.0000	1.0000					
1.5450e+06	1.0000	7.2000	1.0000	1.0000					
1.5500e+06	1.0000	7.2000	1.0000	1.0000					
1.5550e+06	1.0000	7.2000	1.0000	1.0000					
1.5600e+06	1.0000	7.2000	1.0000	1.0000					
1.5650e+06	1.0000	7.2000	1.0000	1.0000					
1.5700e+06	1.0000	7.2000	1.0000	1.0000					
1.5750e+06	1.0000	7.2000	1.0000	1.0000					
1.5800e+06	1.0000	7.2000	1.0000	1.0000					
1.5850e+06	1.0000	7.2000	1.0000	1.0000					
1.5900e+06	1.0000	7.2000	1.0000	1.0000					
1.5950e+06	1.0000	7.2000	1.0000	1.0000					
1.6000e+06	1.0000	7.2000	1.0000	1.0000					
1.6050e+06	1.0000	7.2000	1.0000	1.0000					
1.6100e+06	1.0000	7.2000	1.0000	1.0000					
1.6150e+06	1.0000	7.2000	1.0000	1.0000					
1.6200e+06	1.0000	7.2000	1.0000	1.0000					
1.6250e+06	1.0000	7.2000	1.0000	1.0000					
1.6300e+06	1.0000	7.2000	1.0000	1.0000					
1.6350e+06	1.0000	7.2000	1.0000	1.0000					
1.6400e+06	1.0000	7.2000	1.0000	1.0000					
1.6450e+06	1.0000	7.2000	1.0000	1.0000					
1.6500e+06	1.0000	7.2000	1.0000	1.0000					
1.6550e+06	1.0000	7.2000	1.0000	1.0000					
1.6600e+06	1.0000	7.2000	1.0000	1.0000					
1.6650e+06	1.0000	7.2000	1.0000	1.0000					
1.6700e+06	1.0000	7.2000	1.0000	1.0000					
1.6750e+06	1.0000	7.2000	1.0000	1.0000					
1.6800e+06	1.0000	7.2000	1.0000	1.0000					
1.6850e+06	1.0000	7.2000	1.0000	1.0000					
1.6900e+06	1.0000	7.2000	1.0000	1.0000					
1.6950e+06	1.0000	7.2000	1.0000	1.0000					
1.7000e+06	1.0000	7.2000	1.0000	1.0000					
1.7050e+06	1.0000	7.2000	1.0000	1.0000					
1.7100e+06	1.0000	7.2000	1.0000	1.0000					
1.7150e+06	1.0000	7.2000	1.0000	1.0000					
1.7200e+06	1.0000	7.2000	1.0000	1.0000					
1.7250e+06	1.0000	7.2000	1.0000	1.0000					
1.7300e+06	1.0000	7.2000	1.0000	1.0000					
1.7350e+06	1.0000	7.2000	1.0000	1.0000					
1.7400e+06	1.0000	7.2000	1.0000	1.0000					
1.7450e+06	1.0000	7.2000	1.0000	1.0000					
1.7500e+06	1.0000	7.2000	1.0000	1.0000					
1.7550e+06	1.0000	7.2000	1.0000	1.0000					
1.7600e+06	1.0000	7.2000	1.0000	1.0000					
1.7650e+06	1.0000	7.2000	1.0000	1.0000					
1.7700e+06	1.0000	7.2000	1.0000	1.0000					
1.7750e+06	1.0000	7.2000	1.0000	1.0000					
1.7800e+06	1.0000	7.2000	1.0000	1.0000					
1.7850e+06	1.0000	7.2000	1.0000	1.0000					
1.7900e+06	1.0000	7.2000	1.0000	1.0000					
1.7950e+06	1.0000	7.2000	1.0000	1.0000					
1.8000e+06	1.0000	7.2000	1.0000	1.0000					
1.8050e+06	1.0000	7.2000	1.0000	1.0000					
1.8100e+06	1.0000	7.2000	1.0000	1.0000					
1.8150e+06	1.0000	7.2000	1.0000	1.0000					
1.8200e+06	1.0000	7.2000	1.0000	1.0000					
1.8250e+06	1.0000	7.2000	1.0000	1.0000					
1.8300e+06	1.0000	7.2000	1.0000	1.0000					
1.8350e+06	1.0000	7.2000	1.0000	1.0000					
1.8400e+06	1.0000	7.2000	1.0000	1.0000					
1.8450e+06	1.0000	7.2000	1.0000	1.0000					
1.8500e+06	1.0000	7.2000	1.0000	1.0000					
1.8550e+06	1.0000	7.2000	1.0000	1.0000					
1.8600e+06	1.0000	7.2000	1.0000	1.0000					
1.8650e+06	1.0000	7.2000	1.0000	1.0000					
1.8700e+06	1.0000	7.2000	1.0000	1.0000					
1.8750e+06	1.0000	7.2000	1.0000	1.0000					
1.8800e+06	1.0000	7.2000	1.0000	1.0000					
1.8850e+06	1.0000	7.2000	1.0000	1.0000					
1.8900e+06	1.0000	7.2000	1.0000	1.0000					
1.8950e+06	1.0000	7.2000	1.0000	1.0000					
1.9000e+06	1.0000	7.2000	1.0000	1.0000					
1.9050e+06	1.0000	7.2000	1.0000	1.0000					
1.9100e+06	1.0000	7.2000	1.0000	1.0000					
1.9150e+06	1.0000	7.2000	1.0000	1.0000					
1.9200e+06	1.0000	7.2000	1.0000	1.0000					
1.9250e+06	1.0000	7.2000	1.0000	1.0000					
1.9300e+06	1.0000	7.2000	1.0000	1.0000					
1.9350e+06	1.0000	7.2000	1.0000	1.0000					
1.9400e+06	1.0000	7.2000	1.0000	1.0000					
1.9450e+06	1.0000	7.2000	1.0000	1.0000					
1.9500e+06	1.0000	7.2000	1.0000	1.0000""".format(int(diameter.to(u.m).value))
	outfile = open("alma_{}".format(int(diameter.to(u.m).value)), 'w')
	outfile.write(telescope_file_text)
	outfile.close()
	
diameter = get_diameter_size()
write_alma_telescope_file(diameter)